# Security Policy

## Supported Versions

Only the latest major version of **Parishad** is officially supported with security updates.

| Version | Supported          |
| ------- | ------------------ |
| 0.1.x   | :white_check_mark: |

## Reporting a Vulnerability

We take security seriously. If you discover a security vulnerability in Parishad, please do **NOT** open a public issue.

Instead, please report it via email to:
**security@parishad-council.org** (Example)

Please include:
*   A description of the vulnerability.
*   Steps to reproduce the issue.
*   Affected versions.

We will review your report and respond within 48 hours. Validated security patches will be prioritized for immediate release.
